@@ -16,7 +16,7 @@ class init_anim:
     Sets up the global animation information such speed up and global scale
 
     :param np.ndarray t: contains the time information that corresponds with the six degrees of freedom data 
-    :param: float speed_up: the 'real time speed up' or the ratio of the duration of the data to the duration of the animation 
+    :param float speed_up: the 'real time speed up' or the ratio of the duration of the data to the duration of the animation 
     :param float scale: global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
     """
     def __init__(self, t, speed_up, scale):
@@ -93,12 +93,10 @@ class ref_frame:
         May be useful for offsetting the reference frame from the parent object (i.e. for center of mass of principal axes offset)
 
 
-        Arguments:
-        ----------
-            :param np.ndarray quat: an numpy array of one quaternion
-            :param float x: the x position 
-            :param float y: the y position 
-            :param float z: the z position 
+        :param np.ndarray quat: an numpy array of one quaternion
+        :param float x: the x position 
+        :param float y: the y position 
+        :param float z: the z position 
 
         """
         if not(quat is None):
@@ -375,14 +373,14 @@ class anim_text:
     Creates animated text
 
 
-        :param str name: the Blender object name of the text ('_text' will be appended to this name)
-        :param bpy.data.object parent: the Blender object parent of this text 
-        :param anim: class object that was used to initialize the animation
-        :type anim: :class:`bpsci.core.anim`
-        :param np.ndarray data: the data to be displayed (same length as the number of animated frames)
-        :param str label: a label to append to the text (if no label is desired, pass '')
-        :param int fix_place: the number of decimal places to fix the text to
-        :param bool if_str: whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
+    :param str name: the Blender object name of the text ('_text' will be appended to this name)
+    :param bpy.data.object parent: the Blender object parent of this text 
+    :param anim: class object that was used to initialize the animation
+    :type anim: :class:`bpsci.core.anim`
+    :param np.ndarray data: the data to be displayed (same length as the number of animated frames)
+    :param str label: a label to append to the text (if no label is desired, pass '')
+    :param int fix_place: the number of decimal places to fix the text to
+    :param bool if_str: whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
 
     """
     def __init__(self, name, parent, anim, data, label, fix_place, if_str):
